@@ -10,26 +10,25 @@ our $VERSION = '0.10';
 
 use Role::MethodReturns;
 
-use Types::Standard qw/Undef/;
+use OpenTracing::Types qw/Span/;
 
 
 
 around close => instance_method ( ) {
     
-    returns( Undef,
+    returns_self( $instance,
         
         $original->( $instance => ( ) )
         
     );
     
-    return # we do not really want it to return undef, as perl relies on context
 };
 
 
 
 around get_span => instance_method ( ) {
     
-    returns_object_does_interface( 'OpenTracing::Interface::Span' ,
+    returns( Span ,
         
         $original->( $instance => ( ) )
         
