@@ -10,31 +10,29 @@ our $VERSION = '0.10';
 
 use Role::MethodReturns;
 
+use OpenTracing::Types qw/SpanContext/;
 use Types::Standard qw/Str Value/;
 
 
 
 around get_baggage_item => instance_method ( Str $key ) {
     
-    maybe_returns( Value,
-        
+    returns_maybe( Value,
         $original->( $instance => ( $key ) )
-        
     )
+    
 };
 
 
 
 around with_baggage_item => instance_method ( Str $key, Str $value ) {
     
-    returns_object_does_interface( __PACKAGE__ ,
-        
+    returns( SpanContext ,
         $original->( $instance => ( $key, $value ) )
-        
     )
+    
 };
 
 
 
 1;
-
