@@ -10,7 +10,7 @@ OpenTracing::Types - Type constraints for checking Interfaces
 
 
 
-our $VERSION = 'v0.206.1';
+our $VERSION = '0.12';
 
 
 
@@ -57,7 +57,7 @@ use Type::Utils qw/duck_type/;
 # The OpenTracing::Interface::*.pod files are leading, not the code.
 #
 use constant {
-    REQUIRED_METHODS_FOR_CONTEXT_REFERENCE => [ qw(
+    REQUIRED_METHODS_FOR_REFERENCE => [ qw(
         new_child_of
         new_follows_from
         get_referenced_context
@@ -68,7 +68,7 @@ use constant {
         close
         get_span
     ) ],
-    REQUIRED_METHODS_FOR_SCOPE_MANAGER => [ qw(
+    REQUIRED_METHODS_FOR_SCOPEMANAGER => [ qw(
         activate_span
         get_active_scope
     ) ],
@@ -76,20 +76,14 @@ use constant {
         get_context
         overwrite_operation_name
         finish
-        add_tag
-        add_tags
-        get_tags
+        set_tag
         log_data
-        add_baggage_item
-        add_baggage_items
+        set_baggage_item
         get_baggage_item
-        get_baggage_items
     ) ],
-    REQUIRED_METHODS_FOR_SPAN_CONTEXT => [ qw(
+    REQUIRED_METHODS_FOR_SPANCONTEXT => [ qw(
         get_baggage_item
-        get_baggage_items
         with_baggage_item
-        with_baggage_items
     ) ],
     REQUIRED_METHODS_FOR_TRACER => [ qw(
         get_scope_manager
@@ -103,12 +97,12 @@ use constant {
 
 # XXX DO NOT COPY PASTE FROM CODE, READ THE POD
 
-duck_type ContextReference => REQUIRED_METHODS_FOR_CONTEXT_REFERENCE;
-duck_type Scope            => REQUIRED_METHODS_FOR_SCOPE;
-duck_type ScopeManager     => REQUIRED_METHODS_FOR_SCOPE_MANAGER;
-duck_type Span             => REQUIRED_METHODS_FOR_SPAN;
-duck_type SpanContext      => REQUIRED_METHODS_FOR_SPAN_CONTEXT;
-duck_type Tracer           => REQUIRED_METHODS_FOR_TRACER;
+duck_type Reference    => REQUIRED_METHODS_FOR_REFERENCE;
+duck_type Scope        => REQUIRED_METHODS_FOR_SCOPE;
+duck_type ScopeManager => REQUIRED_METHODS_FOR_SCOPEMANAGER;
+duck_type Span         => REQUIRED_METHODS_FOR_SPAN;
+duck_type SpanContext  => REQUIRED_METHODS_FOR_SPANCONTEXT;
+duck_type Tracer       => REQUIRED_METHODS_FOR_TRACER;
 
 
 
@@ -120,7 +114,7 @@ The following Duck Types are being defined with the mentioned required methods:
 
 
 
-=head2 C<< ContextReference >>
+=head2 C<< Reference >>
 
 =over
 
@@ -136,8 +130,8 @@ The following Duck Types are being defined with the mentioned required methods:
 
 =back
 
-See also L<OpenTracing::Interface::ContextReference/"INSTANCE METHODS">
-and L<OpenTracing::Interface::ContextReference/"CONSTRUCTOR METHODS">.
+See also L<OpenTracing::Interface::Reference/"INSTANCE METHODS">
+and L<OpenTracing::Interface::Reference/"CONSTRUCTOR METHODS">.
 
 
 
@@ -182,7 +176,7 @@ See also L<OpenTracing::Interface::ScopeManager/"INSTANCE METHODS">.
 
 =item C<< log_data >>
 
-=item C<< add_baggage_item >>
+=item C<< set_baggage_item >>
 
 =item C<< get_baggage_item >>
 
@@ -238,7 +232,7 @@ Theo van Hoesel <tvanhoesel@perceptyx.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-'OpenTracing Types' is Copyright (C) 2020 .. 2021, Perceptyx Inc
+'OpenTracing Types' is Copyright (C) 2020, Perceptyx Inc
 
 This library is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0.
